BlobPagerAndVerifier

Struct BlobPagerAndVerifier 

pub struct BlobPagerAndVerifier { /* private fields */ }
Coordinates between FxBlob, the block driver, and the kernel to manage pager-backed blobs such that page requests can be handled at the driver instead of the filesystem layer.

BlobPagerAndVerifier uses a dedicated Pager to create pager-backed VMOs for blobs. Kernel page faults on these VMOs are routed directly to the block driver, which reads and decompresses the raw data. The driver then passes this data back to BlobPagerAndVerifier for cryptographic verification and page fault resolution.

Implementations

Source

impl BlobPagerAndVerifier

pub fn delivery_vmo(&self) -> &Vmo

Returns a reference to the shared delivery queue VMO.

pub async fn new( mapping_provider: &MappingProviderProxy, mapper: &MapperProxy, ) -> Result<Self, Error>

Creates a new BlobPagerAndVerifier.

Establishes a mapping_provider session with FxBlob to receive a shared VMO that will be used to communicate opened blob extent mappings as well as any closed blobs. Then, opens a mapper session with the block driver, forwarding the mapping VMO alongside a Zircon port (for the driver to receive page faults) and a delivery queue VMO (for the driver to emit unverified data for verification).

pub async fn create_vmo(&self, identifier: &[u8; 32]) -> Result<Vmo, Error>

Create pager owned VMO for the blob identified by its Merkle Root Hash.