pub struct UnverifiedPages<'a> { /* private fields */ }Expand description
Unverified data pages delivered from the driver to be verified.
Implementations
Sourceimpl<'a> UnverifiedPages<'a>
impl<'a> UnverifiedPages<'a>
Sourcepub fn len_in_bytes(&self) -> usize
pub fn len_in_bytes(&self) -> usize
Returns the length of the payload in bytes.
Sourcepub fn len_in_pages(&self) -> usize
pub fn len_in_pages(&self) -> usize
Returns the length of the payload in pages.
Sourcepub fn delivery_offset(&self) -> u64
pub fn delivery_offset(&self) -> u64
Returns the byte offset within the shared delivery VMO.
Sourcepub fn as_ptr_byte_slice(&self) -> PtrByteSlice<'a> ⓘ
pub fn as_ptr_byte_slice(&self) -> PtrByteSlice<'a> ⓘ
Returns the underlying raw pointer byte slice to the unverified data.